"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.saml.federation_pb2
import yandex.cloud.organizationmanager.v1.user_account_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetFederationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to return.
    To get the federation ID, make a [FederationService.List] request.
    """
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___GetFederationRequest = GetFederationRequest

@typing.final
class ListFederationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to list federations in.
    To get the organization ID, make a [yandex.cloud.organizationmanager.v1.OrganizationService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListFederationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListFederationsResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on the [Federation.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFederationsRequest = ListFederationsRequest

@typing.final
class ListFederationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListFederationsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListFederationsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def federations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.saml.federation_pb2.Federation]:
        """List of federations."""

    def __init__(
        self,
        *,
        federations: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.saml.federation_pb2.Federation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federations", b"federations", "next_page_token", b"next_page_token"]) -> None: ...

global___ListFederationsResponse = ListFederationsResponse

@typing.final
class CreateFederationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    COOKIE_MAX_AGE_FIELD_NUMBER: builtins.int
    AUTO_CREATE_ACCOUNT_ON_LOGIN_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    SSO_BINDING_FIELD_NUMBER: builtins.int
    SSO_URL_FIELD_NUMBER: builtins.int
    SECURITY_SETTINGS_FIELD_NUMBER: builtins.int
    CASE_INSENSITIVE_NAME_IDS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to create a federation in.
    To get the organization ID, make a [yandex.cloud.organizationmanager.v1.OrganizationService.List] request.
    """
    name: builtins.str
    """Name of the federation.
    The name must be unique within the organization.
    """
    description: builtins.str
    """Description of the federation."""
    auto_create_account_on_login: builtins.bool
    """Add new users automatically on successful authentication.
    The user becomes member of the organization automatically,
    but you need to grant other roles to them.

    If the value is `false`, users who aren't added to the organization
    can't log in, even if they have authenticated on your server.
    """
    issuer: builtins.str
    """ID of the IdP server to be used for authentication.
    The IdP server also responds to IAM with this ID after the user authenticates.
    """
    sso_binding: yandex.cloud.organizationmanager.v1.saml.federation_pb2.BindingType.ValueType
    """Single sign-on endpoint binding type. Most Identity Providers support the `POST` binding type.

    SAML Binding is a mapping of a SAML protocol message onto standard messaging
    formats and/or communications protocols.
    """
    sso_url: builtins.str
    """Single sign-on endpoint URL.
    Specify the link to the IdP login page here.
    """
    case_insensitive_name_ids: builtins.bool
    """Use case insensitive Name IDs."""
    @property
    def cookie_max_age(self) -> google.protobuf.duration_pb2.Duration:
        """Browser cookie lifetime in seconds.
        If the cookie is still valid, the management console
        authenticates the user immediately and redirects them to the home page.
        The default value is `8h`.
        """

    @property
    def security_settings(self) -> yandex.cloud.organizationmanager.v1.saml.federation_pb2.FederationSecuritySettings:
        """Federation security settings."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        cookie_max_age: google.protobuf.duration_pb2.Duration | None = ...,
        auto_create_account_on_login: builtins.bool = ...,
        issuer: builtins.str = ...,
        sso_binding: yandex.cloud.organizationmanager.v1.saml.federation_pb2.BindingType.ValueType = ...,
        sso_url: builtins.str = ...,
        security_settings: yandex.cloud.organizationmanager.v1.saml.federation_pb2.FederationSecuritySettings | None = ...,
        case_insensitive_name_ids: builtins.bool = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cookie_max_age", b"cookie_max_age", "security_settings", b"security_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_create_account_on_login", b"auto_create_account_on_login", "case_insensitive_name_ids", b"case_insensitive_name_ids", "cookie_max_age", b"cookie_max_age", "description", b"description", "issuer", b"issuer", "labels", b"labels", "name", b"name", "organization_id", b"organization_id", "security_settings", b"security_settings", "sso_binding", b"sso_binding", "sso_url", b"sso_url"]) -> None: ...

global___CreateFederationRequest = CreateFederationRequest

@typing.final
class CreateFederationMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation that is being created."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___CreateFederationMetadata = CreateFederationMetadata

@typing.final
class UpdateFederationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    COOKIE_MAX_AGE_FIELD_NUMBER: builtins.int
    AUTO_CREATE_ACCOUNT_ON_LOGIN_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    SSO_BINDING_FIELD_NUMBER: builtins.int
    SSO_URL_FIELD_NUMBER: builtins.int
    SECURITY_SETTINGS_FIELD_NUMBER: builtins.int
    CASE_INSENSITIVE_NAME_IDS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to update.
    To get the federation ID, make a [FederationService.List] request.
    """
    name: builtins.str
    """Name of the federation.
    The name must be unique within the organization.
    """
    description: builtins.str
    """Description of the federation."""
    auto_create_account_on_login: builtins.bool
    """Add new users automatically on successful authentication.
    The user becomes member of the organization automatically,
    but you need to grant other roles to them.

    If the value is `false`, users who aren't added to the organization
    can't log in, even if they have authenticated on your server.
    """
    issuer: builtins.str
    """ID of the IdP server to be used for authentication.
    The IdP server also responds to IAM with this ID after the user authenticates.
    """
    sso_binding: yandex.cloud.organizationmanager.v1.saml.federation_pb2.BindingType.ValueType
    """Single sign-on endpoint binding type. Most Identity Providers support the `POST` binding type.

    SAML Binding is a mapping of a SAML protocol message onto standard messaging
    formats and/or communications protocols.
    """
    sso_url: builtins.str
    """Single sign-on endpoint URL.
    Specify the link to the IdP login page here.
    """
    case_insensitive_name_ids: builtins.bool
    """Use case insensitive name ids."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the federation are going to be updated."""

    @property
    def cookie_max_age(self) -> google.protobuf.duration_pb2.Duration:
        """Browser cookie lifetime in seconds.
        If the cookie is still valid, the management console
        authenticates the user immediately and redirects them to the home page.
        The default value is `8h`.
        """

    @property
    def security_settings(self) -> yandex.cloud.organizationmanager.v1.saml.federation_pb2.FederationSecuritySettings:
        """Federation security settings."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        cookie_max_age: google.protobuf.duration_pb2.Duration | None = ...,
        auto_create_account_on_login: builtins.bool = ...,
        issuer: builtins.str = ...,
        sso_binding: yandex.cloud.organizationmanager.v1.saml.federation_pb2.BindingType.ValueType = ...,
        sso_url: builtins.str = ...,
        security_settings: yandex.cloud.organizationmanager.v1.saml.federation_pb2.FederationSecuritySettings | None = ...,
        case_insensitive_name_ids: builtins.bool = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cookie_max_age", b"cookie_max_age", "security_settings", b"security_settings", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_create_account_on_login", b"auto_create_account_on_login", "case_insensitive_name_ids", b"case_insensitive_name_ids", "cookie_max_age", b"cookie_max_age", "description", b"description", "federation_id", b"federation_id", "issuer", b"issuer", "labels", b"labels", "name", b"name", "security_settings", b"security_settings", "sso_binding", b"sso_binding", "sso_url", b"sso_url", "update_mask", b"update_mask"]) -> None: ...

global___UpdateFederationRequest = UpdateFederationRequest

@typing.final
class UpdateFederationMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation that is being updated."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___UpdateFederationMetadata = UpdateFederationMetadata

@typing.final
class DeleteFederationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to delete.
    To get the federation ID, make a [FederationService.List] request.
    """
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___DeleteFederationRequest = DeleteFederationRequest

@typing.final
class DeleteFederationMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation that is being deleted."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___DeleteFederationMetadata = DeleteFederationMetadata

@typing.final
class AddFederatedUserAccountsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    NAME_IDS_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to add users."""
    @property
    def name_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Name IDs returned by the Identity Provider (IdP) on successful authentication.
        These may be UPNs or user email addresses.
        """

    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        name_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id", "name_ids", b"name_ids"]) -> None: ...

global___AddFederatedUserAccountsRequest = AddFederatedUserAccountsRequest

@typing.final
class AddFederatedUserAccountsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation that is being altered."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___AddFederatedUserAccountsMetadata = AddFederatedUserAccountsMetadata

@typing.final
class AddFederatedUserAccountsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ACCOUNTS_FIELD_NUMBER: builtins.int
    @property
    def user_accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.user_account_pb2.UserAccount]:
        """List of users created by [FederationService.AddUserAccounts] request."""

    def __init__(
        self,
        *,
        user_accounts: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.user_account_pb2.UserAccount] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_accounts", b"user_accounts"]) -> None: ...

global___AddFederatedUserAccountsResponse = AddFederatedUserAccountsResponse

@typing.final
class DeleteFederatedUserAccountsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    SUBJECT_IDS_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to delete users from."""
    @property
    def subject_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of subjects to delete."""

    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        subject_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id", "subject_ids", b"subject_ids"]) -> None: ...

global___DeleteFederatedUserAccountsRequest = DeleteFederatedUserAccountsRequest

@typing.final
class DeleteFederatedUserAccountsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation that is being altered."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id"]) -> None: ...

global___DeleteFederatedUserAccountsMetadata = DeleteFederatedUserAccountsMetadata

@typing.final
class DeleteFederatedUserAccountsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_SUBJECTS_FIELD_NUMBER: builtins.int
    NON_EXISTING_SUBJECTS_FIELD_NUMBER: builtins.int
    @property
    def deleted_subjects(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of subjects deleted by [FederationService.DeleteUserAccounts] request."""

    @property
    def non_existing_subjects(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of subjects found in [FederationService.DeleteUserAccounts] request that do not exist."""

    def __init__(
        self,
        *,
        deleted_subjects: collections.abc.Iterable[builtins.str] | None = ...,
        non_existing_subjects: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deleted_subjects", b"deleted_subjects", "non_existing_subjects", b"non_existing_subjects"]) -> None: ...

global___DeleteFederatedUserAccountsResponse = DeleteFederatedUserAccountsResponse

@typing.final
class ListFederatedUserAccountsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to list user accounts for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListFederatedUserAccountsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListFederatedUserAccountsResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on the [name_id] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 1-1000 characters long and match the regular expression
      `[a-z0-9A-Z/@_.\\-=+*\\\\]+`.
    """
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFederatedUserAccountsRequest = ListFederatedUserAccountsRequest

@typing.final
class ListFederatedUserAccountsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ACCOUNTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListFederatedUserAccountsRequest.page_size], use the [next_page_token] as the value
    for the [ListFederatedUserAccountsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def user_accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.user_account_pb2.UserAccount]:
        """List of user accounts for the specified federation."""

    def __init__(
        self,
        *,
        user_accounts: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.user_account_pb2.UserAccount] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "user_accounts", b"user_accounts"]) -> None: ...

global___ListFederatedUserAccountsResponse = ListFederatedUserAccountsResponse

@typing.final
class ListFederationOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListFederationOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListFederationOperationsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFederationOperationsRequest = ListFederationOperationsRequest

@typing.final
class ListFederationOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListFederationOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListFederationOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified federation."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListFederationOperationsResponse = ListFederationOperationsResponse

@typing.final
class GetFederationDomainRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to get domain information for.
    To get the federation ID, make a [FederationService.List] request.
    """
    domain: builtins.str
    """Domain name to get information for.
    Must be a valid domain name (1-253 characters).
    """
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "federation_id", b"federation_id"]) -> None: ...

global___GetFederationDomainRequest = GetFederationDomainRequest

@typing.final
class ListFederationDomainsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to list domains for.
    To get the federation ID, make a [FederationService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListFederationDomainsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListFederationDomainsResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression supports the following operations:
    - `=` for exact match: `domain = 'domain-1.com'`
    - `IN` for multiple values: `status IN ('NEED_TO_VALIDATE', 'VALID')`
    - `contains` for domain substring search: `domain contains '3'`
    - `AND` for combining conditions: `status = 'INVALID' AND domain contains '3'`

    Available fields for filtering:
    - `domain` - domain name
    - `status` - domain validation status

    Must be 1-1000 characters long.
    """
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["federation_id", b"federation_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListFederationDomainsRequest = ListFederationDomainsRequest

@typing.final
class ListFederationDomainsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAINS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListFederationDomainsRequest.page_size], use the [next_page_token] as the value
    for the [ListFederationDomainsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def domains(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.saml.federation_pb2.Domain]:
        """List of domains for the specified federation."""

    def __init__(
        self,
        *,
        domains: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.saml.federation_pb2.Domain] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domains", b"domains", "next_page_token", b"next_page_token"]) -> None: ...

global___ListFederationDomainsResponse = ListFederationDomainsResponse

@typing.final
class AddFederationDomainRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to add a domain to.
    To get the federation ID, make a [FederationService.List] request.
    """
    domain: builtins.str
    """Domain name to add to the federation.
    Must be a valid domain name (1-253 characters).
    """
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "federation_id", b"federation_id"]) -> None: ...

global___AddFederationDomainRequest = AddFederationDomainRequest

@typing.final
class AddFederationDomainMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation that the domain is being added to."""
    domain: builtins.str
    """Domain name that is being added to the federation."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "federation_id", b"federation_id"]) -> None: ...

global___AddFederationDomainMetadata = AddFederationDomainMetadata

@typing.final
class ValidateFederationDomainRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to validate a domain for.
    To get the federation ID, make a [FederationService.List] request.
    """
    domain: builtins.str
    """Domain name to validate for the federation.
    Must be a valid domain name (1-253 characters).
    """
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "federation_id", b"federation_id"]) -> None: ...

global___ValidateFederationDomainRequest = ValidateFederationDomainRequest

@typing.final
class ValidateFederationDomainMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation that the domain validation is being performed for."""
    domain: builtins.str
    """Domain name that is being validated for the federation."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "federation_id", b"federation_id"]) -> None: ...

global___ValidateFederationDomainMetadata = ValidateFederationDomainMetadata

@typing.final
class DeleteFederationDomainRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation to delete a domain from.
    To get the federation ID, make a [FederationService.List] request.
    """
    domain: builtins.str
    """Domain name to delete from the federation.
    Must be a valid domain name (1-253 characters).
    """
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "federation_id", b"federation_id"]) -> None: ...

global___DeleteFederationDomainRequest = DeleteFederationDomainRequest

@typing.final
class DeleteFederationDomainMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEDERATION_ID_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    federation_id: builtins.str
    """ID of the federation that the domain is being deleted from."""
    domain: builtins.str
    """Domain name that is being deleted from the federation."""
    def __init__(
        self,
        *,
        federation_id: builtins.str = ...,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "federation_id", b"federation_id"]) -> None: ...

global___DeleteFederationDomainMetadata = DeleteFederationDomainMetadata



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/quotamanager/v1/quota_request_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/quotamanager/v1/quota_request_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.quotamanager.v1 import quota_request_pb2 as yandex_dot_cloud_dot_quotamanager_dot_v1_dot_quota__request__pb2
from yandex.cloud.quotamanager.v1 import resource_pb2 as yandex_dot_cloud_dot_quotamanager_dot_v1_dot_resource__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/quotamanager/v1/quota_request_service.proto\x12\x1cyandex.cloud.quotamanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x30yandex/cloud/quotamanager/v1/quota_request.proto\x1a+yandex/cloud/quotamanager/v1/resource.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"@\n\x16GetQuotaRequestRequest\x12&\n\x10quota_request_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xb6\x02\n\x19\x43reateQuotaRequestRequest\x12>\n\x08resource\x18\x01 \x01(\x0b\x32&.yandex.cloud.quotamanager.v1.ResourceB\x04\xe8\xc7\x31\x01\x12r\n\x14\x64\x65sired_quota_limits\x18\x02 \x03(\x0b\x32I.yandex.cloud.quotamanager.v1.CreateQuotaRequestRequest.DesiredQuotaLimitB\t\x82\xc8\x31\x05\x31-100\x1a\x65\n\x11\x44\x65siredQuotaLimit\x12\x1e\n\x08quota_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x30\n\rdesired_limit\x18\x02 \x01(\x01\x42\x19\xfa\xc7\x31\x15\x30-9223372036854775807\"6\n\x1a\x43reateQuotaRequestMetadata\x12\x18\n\x10quota_request_id\x18\x01 \x01(\t\"j\n\x19\x43\x61ncelQuotaRequestRequest\x12&\n\x10quota_request_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12%\n\tquota_ids\x18\x02 \x03(\tB\x12\x82\xc8\x31\x06\x31-1000\x8a\xc8\x31\x04<=64\"6\n\x1a\x43\x61ncelQuotaRequestMetadata\x12\x18\n\x10quota_request_id\x18\x01 \x01(\t\"\xb3\x01\n\x17ListQuotaRequestRequest\x12>\n\x08resource\x18\x01 \x01(\x0b\x32&.yandex.cloud.quotamanager.v1.ResourceB\x04\xe8\xc7\x31\x01\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\"w\n\x18ListQuotaRequestResponse\x12\x42\n\x0equota_requests\x18\x01 \x03(\x0b\x32*.yandex.cloud.quotamanager.v1.QuotaRequest\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x89\x01\n!ListQuotaRequestOperationsRequest\x12&\n\x10quota_request_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"t\n\"ListQuotaRequestOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xd5\x07\n\x13QuotaRequestService\x12\xa3\x01\n\x03Get\x12\x34.yandex.cloud.quotamanager.v1.GetQuotaRequestRequest\x1a*.yandex.cloud.quotamanager.v1.QuotaRequest\":\x82\xd3\xe4\x93\x02\x34\x12\x32/quota-manager/v1/quotaRequests/{quota_request_id}\x12\xbe\x01\n\x06\x43reate\x12\x37.yandex.cloud.quotamanager.v1.CreateQuotaRequestRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2**\n\x1a\x43reateQuotaRequestMetadata\x12\x0cQuotaRequest\x82\xd3\xe4\x93\x02$\"\x1f/quota-manager/v1/quotaRequests:\x01*\x12\xd8\x01\n\x06\x43\x61ncel\x12\x37.yandex.cloud.quotamanager.v1.CancelQuotaRequestRequest\x1a!.yandex.cloud.operation.Operation\"r\xb2\xd2**\n\x1a\x43\x61ncelQuotaRequestMetadata\x12\x0cQuotaRequest\x82\xd3\xe4\x93\x02>\"9/quota-manager/v1/quotaRequests/{quota_request_id}/cancel:\x01*\x12\x9e\x01\n\x04List\x12\x35.yandex.cloud.quotamanager.v1.ListQuotaRequestRequest\x1a\x36.yandex.cloud.quotamanager.v1.ListQuotaRequestResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/quota-manager/v1/quotaRequests\x12\xda\x01\n\x0eListOperations\x12?.yandex.cloud.quotamanager.v1.ListQuotaRequestOperationsRequest\x1a@.yandex.cloud.quotamanager.v1.ListQuotaRequestOperationsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/quota-manager/v1/quotaRequests/{quota_request_id}/operationsBq\n yandex.cloud.api.quotamanager.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/quotamanager/v1;quotamanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.quotamanager.v1.quota_request_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.quotamanager.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/quotamanager/v1;quotamanager'
  _globals['_GETQUOTAREQUESTREQUEST'].fields_by_name['quota_request_id']._loaded_options = None
  _globals['_GETQUOTAREQUESTREQUEST'].fields_by_name['quota_request_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEQUOTAREQUESTREQUEST_DESIREDQUOTALIMIT'].fields_by_name['quota_id']._loaded_options = None
  _globals['_CREATEQUOTAREQUESTREQUEST_DESIREDQUOTALIMIT'].fields_by_name['quota_id']._serialized_options = b'\350\3071\001\212\3101\004<=64'
  _globals['_CREATEQUOTAREQUESTREQUEST_DESIREDQUOTALIMIT'].fields_by_name['desired_limit']._loaded_options = None
  _globals['_CREATEQUOTAREQUESTREQUEST_DESIREDQUOTALIMIT'].fields_by_name['desired_limit']._serialized_options = b'\372\3071\0250-9223372036854775807'
  _globals['_CREATEQUOTAREQUESTREQUEST'].fields_by_name['resource']._loaded_options = None
  _globals['_CREATEQUOTAREQUESTREQUEST'].fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _globals['_CREATEQUOTAREQUESTREQUEST'].fields_by_name['desired_quota_limits']._loaded_options = None
  _globals['_CREATEQUOTAREQUESTREQUEST'].fields_by_name['desired_quota_limits']._serialized_options = b'\202\3101\0051-100'
  _globals['_CANCELQUOTAREQUESTREQUEST'].fields_by_name['quota_request_id']._loaded_options = None
  _globals['_CANCELQUOTAREQUESTREQUEST'].fields_by_name['quota_request_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CANCELQUOTAREQUESTREQUEST'].fields_by_name['quota_ids']._loaded_options = None
  _globals['_CANCELQUOTAREQUESTREQUEST'].fields_by_name['quota_ids']._serialized_options = b'\202\3101\0061-1000\212\3101\004<=64'
  _globals['_LISTQUOTAREQUESTREQUEST'].fields_by_name['resource']._loaded_options = None
  _globals['_LISTQUOTAREQUESTREQUEST'].fields_by_name['resource']._serialized_options = b'\350\3071\001'
  _globals['_LISTQUOTAREQUESTREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTQUOTAREQUESTREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTQUOTAREQUESTREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTQUOTAREQUESTREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTQUOTAREQUESTREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTQUOTAREQUESTREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTQUOTAREQUESTOPERATIONSREQUEST'].fields_by_name['quota_request_id']._loaded_options = None
  _globals['_LISTQUOTAREQUESTOPERATIONSREQUEST'].fields_by_name['quota_request_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTQUOTAREQUESTOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTQUOTAREQUESTOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTQUOTAREQUESTOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTQUOTAREQUESTOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_QUOTAREQUESTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_QUOTAREQUESTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0024\0222/quota-manager/v1/quotaRequests/{quota_request_id}'
  _globals['_QUOTAREQUESTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_QUOTAREQUESTSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322**\n\032CreateQuotaRequestMetadata\022\014QuotaRequest\202\323\344\223\002$\"\037/quota-manager/v1/quotaRequests:\001*'
  _globals['_QUOTAREQUESTSERVICE'].methods_by_name['Cancel']._loaded_options = None
  _globals['_QUOTAREQUESTSERVICE'].methods_by_name['Cancel']._serialized_options = b'\262\322**\n\032CancelQuotaRequestMetadata\022\014QuotaRequest\202\323\344\223\002>\"9/quota-manager/v1/quotaRequests/{quota_request_id}/cancel:\001*'
  _globals['_QUOTAREQUESTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_QUOTAREQUESTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/quota-manager/v1/quotaRequests'
  _globals['_QUOTAREQUESTSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_QUOTAREQUESTSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002?\022=/quota-manager/v1/quotaRequests/{quota_request_id}/operations'
  _globals['_GETQUOTAREQUESTREQUEST']._serialized_start=320
  _globals['_GETQUOTAREQUESTREQUEST']._serialized_end=384
  _globals['_CREATEQUOTAREQUESTREQUEST']._serialized_start=387
  _globals['_CREATEQUOTAREQUESTREQUEST']._serialized_end=697
  _globals['_CREATEQUOTAREQUESTREQUEST_DESIREDQUOTALIMIT']._serialized_start=596
  _globals['_CREATEQUOTAREQUESTREQUEST_DESIREDQUOTALIMIT']._serialized_end=697
  _globals['_CREATEQUOTAREQUESTMETADATA']._serialized_start=699
  _globals['_CREATEQUOTAREQUESTMETADATA']._serialized_end=753
  _globals['_CANCELQUOTAREQUESTREQUEST']._serialized_start=755
  _globals['_CANCELQUOTAREQUESTREQUEST']._serialized_end=861
  _globals['_CANCELQUOTAREQUESTMETADATA']._serialized_start=863
  _globals['_CANCELQUOTAREQUESTMETADATA']._serialized_end=917
  _globals['_LISTQUOTAREQUESTREQUEST']._serialized_start=920
  _globals['_LISTQUOTAREQUESTREQUEST']._serialized_end=1099
  _globals['_LISTQUOTAREQUESTRESPONSE']._serialized_start=1101
  _globals['_LISTQUOTAREQUESTRESPONSE']._serialized_end=1220
  _globals['_LISTQUOTAREQUESTOPERATIONSREQUEST']._serialized_start=1223
  _globals['_LISTQUOTAREQUESTOPERATIONSREQUEST']._serialized_end=1360
  _globals['_LISTQUOTAREQUESTOPERATIONSRESPONSE']._serialized_start=1362
  _globals['_LISTQUOTAREQUESTOPERATIONSRESPONSE']._serialized_end=1478
  _globals['_QUOTAREQUESTSERVICE']._serialized_start=1481
  _globals['_QUOTAREQUESTSERVICE']._serialized_end=2462
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class StreamLine(google.protobuf.message.Message):
    """Entity representing the incoming video signal settings."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    RTMP_PUSH_FIELD_NUMBER: builtins.int
    RTMP_PULL_FIELD_NUMBER: builtins.int
    MANUAL_LINE_FIELD_NUMBER: builtins.int
    AUTO_LINE_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the line."""
    channel_id: builtins.str
    """ID of the channel to which this stream line belongs."""
    title: builtins.str
    """Title of the stream line."""
    @property
    def rtmp_push(self) -> global___RTMPPushInput:
        """Real-Time Messaging Protocol (RTMP) push input type."""

    @property
    def rtmp_pull(self) -> global___RTMPPullInput:
        """Real-Time Messaging Protocol (RTMP) pull input type."""

    @property
    def manual_line(self) -> global___ManualLine:
        """Manual stream control."""

    @property
    def auto_line(self) -> global___AutoLine:
        """Automatic stream control."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the stream line was initially created in the system."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the last modification to the stream line or its metadata."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom user-defined labels as `key:value` pairs.
        Maximum 64 labels per stream line.
        Labels can be used for organization, filtering, and metadata purposes.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        rtmp_push: global___RTMPPushInput | None = ...,
        rtmp_pull: global___RTMPPullInput | None = ...,
        manual_line: global___ManualLine | None = ...,
        auto_line: global___AutoLine | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["auto_line", b"auto_line", "created_at", b"created_at", "input_type", b"input_type", "line_type", b"line_type", "manual_line", b"manual_line", "rtmp_pull", b"rtmp_pull", "rtmp_push", b"rtmp_push", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auto_line", b"auto_line", "channel_id", b"channel_id", "created_at", b"created_at", "id", b"id", "input_type", b"input_type", "labels", b"labels", "line_type", b"line_type", "manual_line", b"manual_line", "rtmp_pull", b"rtmp_pull", "rtmp_push", b"rtmp_push", "title", b"title", "updated_at", b"updated_at"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["input_type", b"input_type"]) -> typing.Literal["rtmp_push", "rtmp_pull"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["line_type", b"line_type"]) -> typing.Literal["manual_line", "auto_line"] | None: ...

global___StreamLine = StreamLine

@typing.final
class PushStreamKey(google.protobuf.message.Message):
    """Represents the stream key used for pushing video streams."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.str
    """The unique stream key."""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key", b"key"]) -> None: ...

global___PushStreamKey = PushStreamKey

@typing.final
class RTMPPushInput(google.protobuf.message.Message):
    """Settings for an RTMP (Real-Time Messaging Protocol) push input.
    Used when the video stream is pushed to an RTMP server.
    @see https://en.wikipedia.org/wiki/Real-Time_Messaging_Protocol
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """RTMP server url."""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

global___RTMPPushInput = RTMPPushInput

@typing.final
class RTMPPullInput(google.protobuf.message.Message):
    """Settings for an RTMP pull input.
    Used when the service pulls the video stream from an RTMP source.
    @see https://en.wikipedia.org/wiki/Real-Time_Messaging_Protocol
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """RTMP url for receiving video signal."""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

global___RTMPPullInput = RTMPPullInput

@typing.final
class ManualLine(google.protobuf.message.Message):
    """Represents a manual line type where the stream control is handled manually.
    This means that stream start/stop actions are performed by the user.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ManualLine = ManualLine

@typing.final
class AutoLine(google.protobuf.message.Message):
    """Represents an automatic line type where the stream control is handled automatically."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _AutoLineStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AutoLineStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AutoLine._AutoLineStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        AUTO_LINE_STATUS_UNSPECIFIED: AutoLine._AutoLineStatus.ValueType  # 0
        """Auto line status unspecified."""
        DEACTIVATED: AutoLine._AutoLineStatus.ValueType  # 1
        """The automatic line is deactivated and not currently active."""
        ACTIVE: AutoLine._AutoLineStatus.ValueType  # 2
        """The automatic line is active and operational."""

    class AutoLineStatus(_AutoLineStatus, metaclass=_AutoLineStatusEnumTypeWrapper):
        """Enum representing the status of an automatic stream line.
        Indicates whether the automatic line is active or deactivated.
        """

    AUTO_LINE_STATUS_UNSPECIFIED: AutoLine.AutoLineStatus.ValueType  # 0
    """Auto line status unspecified."""
    DEACTIVATED: AutoLine.AutoLineStatus.ValueType  # 1
    """The automatic line is deactivated and not currently active."""
    ACTIVE: AutoLine.AutoLineStatus.ValueType  # 2
    """The automatic line is active and operational."""

    STATUS_FIELD_NUMBER: builtins.int
    status: global___AutoLine.AutoLineStatus.ValueType
    """The status of the automatic line."""
    def __init__(
        self,
        *,
        status: global___AutoLine.AutoLineStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___AutoLine = AutoLine



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ExternalInstance(google.protobuf.message.Message):
    """ExternalInstance attachment to external service subscription."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_FIELD_NUMBER: builtins.int
    LICENSE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Optional external subscription name."""
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Mapping of vendor defined properties in key, value format."""

    @property
    def subscription(self) -> global___ExternalSubscription: ...
    @property
    def license(self) -> global___ExternalLicense: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        subscription: global___ExternalSubscription | None = ...,
        license: global___ExternalLicense | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["license", b"license", "subscription", b"subscription", "vendor", b"vendor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["license", b"license", "name", b"name", "properties", b"properties", "subscription", b"subscription", "vendor", b"vendor"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["vendor", b"vendor"]) -> typing.Literal["subscription", "license"] | None: ...

global___ExternalInstance = ExternalInstance

@typing.final
class ExternalSubscription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSCRIPTION_ID_FIELD_NUMBER: builtins.int
    LICENSE_ID_FIELD_NUMBER: builtins.int
    ACTIVATION_KEY_FIELD_NUMBER: builtins.int
    subscription_id: builtins.str
    """External subscription id."""
    license_id: builtins.str
    """Optional: paired license id for external subscription."""
    activation_key: builtins.str
    """Optional: default activation key for external subscription."""
    def __init__(
        self,
        *,
        subscription_id: builtins.str = ...,
        license_id: builtins.str = ...,
        activation_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["activation_key", b"activation_key", "license_id", b"license_id", "subscription_id", b"subscription_id"]) -> None: ...

global___ExternalSubscription = ExternalSubscription

@typing.final
class ExternalLicense(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LICENSE_ID_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    license_id: builtins.str
    """External license bound to subscription instance."""
    payload: builtins.bytes
    """License (vendor specific) payload."""
    def __init__(
        self,
        *,
        license_id: builtins.str = ...,
        payload: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["license_id", b"license_id", "payload", b"payload"]) -> None: ...

global___ExternalLicense = ExternalLicense



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/searchapi/v2/search_query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/searchapi/v2/search_query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/searchapi/v2/search_query.proto\x12\x19yandex.cloud.searchapi.v2\x1a\x1dyandex/cloud/validation.proto\"\x9b\x05\n\x0bSearchQuery\x12L\n\x0bsearch_type\x18\x01 \x01(\x0e\x32\x31.yandex.cloud.searchapi.v2.SearchQuery.SearchTypeB\x04\xe8\xc7\x31\x01\x12!\n\nquery_text\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=400\x12\x46\n\x0b\x66\x61mily_mode\x18\x03 \x01(\x0e\x32\x31.yandex.cloud.searchapi.v2.SearchQuery.FamilyMode\x12\x15\n\x04page\x18\x04 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12I\n\rfix_typo_mode\x18\x05 \x01(\x0e\x32\x32.yandex.cloud.searchapi.v2.SearchQuery.FixTypoMode\"\xa2\x01\n\nSearchType\x12\x1b\n\x17SEARCH_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSEARCH_TYPE_RU\x10\x01\x12\x12\n\x0eSEARCH_TYPE_TR\x10\x02\x12\x13\n\x0fSEARCH_TYPE_COM\x10\x03\x12\x12\n\x0eSEARCH_TYPE_KK\x10\x04\x12\x12\n\x0eSEARCH_TYPE_BE\x10\x05\x12\x12\n\x0eSEARCH_TYPE_UZ\x10\x06\"q\n\nFamilyMode\x12\x1b\n\x17\x46\x41MILY_MODE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x46\x41MILY_MODE_NONE\x10\x01\x12\x18\n\x14\x46\x41MILY_MODE_MODERATE\x10\x02\x12\x16\n\x12\x46\x41MILY_MODE_STRICT\x10\x03\"Y\n\x0b\x46ixTypoMode\x12\x1d\n\x19\x46IX_TYPO_MODE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x46IX_TYPO_MODE_ON\x10\x01\x12\x15\n\x11\x46IX_TYPO_MODE_OFF\x10\x02\"\xc4\x01\n\x0eSearchMetadata\x12\x82\x01\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.searchapi.v2.SearchMetadata.FieldsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x65\n\x1ayandex.cloud.api.search.v2ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/searchapi/v2;searchapib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.searchapi.v2.search_query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.search.v2ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/searchapi/v2;searchapi'
  _globals['_SEARCHQUERY'].fields_by_name['search_type']._loaded_options = None
  _globals['_SEARCHQUERY'].fields_by_name['search_type']._serialized_options = b'\350\3071\001'
  _globals['_SEARCHQUERY'].fields_by_name['query_text']._loaded_options = None
  _globals['_SEARCHQUERY'].fields_by_name['query_text']._serialized_options = b'\350\3071\001\212\3101\005<=400'
  _globals['_SEARCHQUERY'].fields_by_name['page']._loaded_options = None
  _globals['_SEARCHQUERY'].fields_by_name['page']._serialized_options = b'\372\3071\003>=0'
  _globals['_SEARCHMETADATA_FIELDSENTRY']._loaded_options = None
  _globals['_SEARCHMETADATA_FIELDSENTRY']._serialized_options = b'8\001'
  _globals['_SEARCHMETADATA'].fields_by_name['fields']._loaded_options = None
  _globals['_SEARCHMETADATA'].fields_by_name['fields']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_SEARCHQUERY']._serialized_start=107
  _globals['_SEARCHQUERY']._serialized_end=774
  _globals['_SEARCHQUERY_SEARCHTYPE']._serialized_start=406
  _globals['_SEARCHQUERY_SEARCHTYPE']._serialized_end=568
  _globals['_SEARCHQUERY_FAMILYMODE']._serialized_start=570
  _globals['_SEARCHQUERY_FAMILYMODE']._serialized_end=683
  _globals['_SEARCHQUERY_FIXTYPOMODE']._serialized_start=685
  _globals['_SEARCHQUERY_FIXTYPOMODE']._serialized_end=774
  _globals['_SEARCHMETADATA']._serialized_start=777
  _globals['_SEARCHMETADATA']._serialized_end=973
  _globals['_SEARCHMETADATA_FIELDSENTRY']._serialized_start=928
  _globals['_SEARCHMETADATA_FIELDSENTRY']._serialized_end=973
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/sqlserver/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/sqlserver/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.mdb.sqlserver.v1.config import sqlserver2016sp2_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_config_dot_sqlserver2016sp2__pb2
from yandex.cloud.mdb.sqlserver.v1.config import sqlserver2017_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_config_dot_sqlserver2017__pb2
from yandex.cloud.mdb.sqlserver.v1.config import sqlserver2019_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_config_dot_sqlserver2019__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/mdb/sqlserver/v1/cluster.proto\x12\x1dyandex.cloud.mdb.sqlserver.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/type/timeofday.proto\x1a;yandex/cloud/mdb/sqlserver/v1/config/sqlserver2016sp2.proto\x1a\x38yandex/cloud/mdb/sqlserver/v1/config/sqlserver2017.proto\x1a\x38yandex/cloud/mdb/sqlserver/v1/config/sqlserver2019.proto\"\xd0\x07\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x42\n\x06labels\x18\x06 \x03(\x0b\x32\x32.yandex.cloud.mdb.sqlserver.v1.Cluster.LabelsEntry\x12G\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32\x32.yandex.cloud.mdb.sqlserver.v1.Cluster.Environment\x12=\n\nmonitoring\x18\x08 \x03(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.Monitoring\x12<\n\x06\x63onfig\x18\t \x01(\x0b\x32,.yandex.cloud.mdb.sqlserver.v1.ClusterConfig\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12=\n\x06health\x18\x0b \x01(\x0e\x32-.yandex.cloud.mdb.sqlserver.v1.Cluster.Health\x12=\n\x06status\x18\x0c \x01(\x0e\x32-.yandex.cloud.mdb.sqlserver.v1.Cluster.Status\x12\x1a\n\x12security_group_ids\x18\r \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0e \x01(\x08\x12\x14\n\x0csqlcollation\x18\x0f \x01(\t\x12\x16\n\x0ehost_group_ids\x18\x10 \x03(\t\x12\x1a\n\x12service_account_id\x18\x11 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xcb\t\n\rClusterConfig\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x85\x01\n\x1bsqlserver_config_2016sp2std\x18\x02 \x01(\x0b\x32\x42.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2016sp2stdH\x00R\x1asqlserverConfig_2016sp2std\x12\x85\x01\n\x1bsqlserver_config_2016sp2ent\x18\x05 \x01(\x0b\x32\x42.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2016sp2entH\x00R\x1asqlserverConfig_2016sp2ent\x12|\n\x18sqlserver_config_2017std\x18\x08 \x01(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2017stdH\x00R\x17sqlserverConfig_2017std\x12|\n\x18sqlserver_config_2017ent\x18\t \x01(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2017entH\x00R\x17sqlserverConfig_2017ent\x12|\n\x18sqlserver_config_2019std\x18\n \x01(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019stdH\x00R\x17sqlserverConfig_2019std\x12|\n\x18sqlserver_config_2019ent\x18\x0b \x01(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019entH\x00R\x17sqlserverConfig_2019ent\x12;\n\tresources\x18\x03 \x01(\x0b\x32(.yandex.cloud.mdb.sqlserver.v1.Resources\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x04 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12\x35\n\x06\x61\x63\x63\x65ss\x18\x06 \x01(\x0b\x32%.yandex.cloud.mdb.sqlserver.v1.Access\x12`\n\x15secondary_connections\x18\x07 \x01(\x0e\x32\x41.yandex.cloud.mdb.sqlserver.v1.ClusterConfig.SecondaryConnections\"\x81\x01\n\x14SecondaryConnections\x12%\n!SECONDARY_CONNECTIONS_UNSPECIFIED\x10\x00\x12\x1d\n\x19SECONDARY_CONNECTIONS_OFF\x10\x01\x12#\n\x1fSECONDARY_CONNECTIONS_READ_ONLY\x10\x02\x42\x12\n\x10sqlserver_config\"\xc5\x03\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12;\n\tresources\x18\x04 \x01(\x0b\x32(.yandex.cloud.mdb.sqlserver.v1.Resources\x12\x36\n\x04role\x18\x05 \x01(\x0e\x32(.yandex.cloud.mdb.sqlserver.v1.Host.Role\x12:\n\x06health\x18\x06 \x01(\x0e\x32*.yandex.cloud.mdb.sqlserver.v1.Host.Health\x12\x38\n\x08services\x18\x07 \x03(\x0b\x32&.yandex.cloud.mdb.sqlserver.v1.Service\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x18\n\x10\x61ssign_public_ip\x18\t \x01(\x08\"1\n\x04Role\x12\x10\n\x0cROLE_UNKNOWN\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xe3\x01\n\x07Service\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.yandex.cloud.mdb.sqlserver.v1.Service.Type\x12=\n\x06health\x18\x02 \x01(\x0e\x32-.yandex.cloud.mdb.sqlserver.v1.Service.Health\"+\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\r\n\tSQLSERVER\x10\x01\"1\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\",\n\x06\x41\x63\x63\x65ss\x12\x11\n\tdata_lens\x18\x01 \x01(\x08\x12\x0f\n\x07web_sql\x18\x02 \x01(\x08\x42u\n!yandex.cloud.api.mdb.sqlserver.v1B\x03PSCZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.sqlserver.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.sqlserver.v1B\003PSCZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserver'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER']._serialized_start=318
  _globals['_CLUSTER']._serialized_end=1294
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=986
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1031
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=1033
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=1106
  _globals['_CLUSTER_HEALTH']._serialized_start=1108
  _globals['_CLUSTER_HEALTH']._serialized_end=1171
  _globals['_CLUSTER_STATUS']._serialized_start=1173
  _globals['_CLUSTER_STATUS']._serialized_end=1294
  _globals['_MONITORING']._serialized_start=1296
  _globals['_MONITORING']._serialized_end=1357
  _globals['_CLUSTERCONFIG']._serialized_start=1360
  _globals['_CLUSTERCONFIG']._serialized_end=2587
  _globals['_CLUSTERCONFIG_SECONDARYCONNECTIONS']._serialized_start=2438
  _globals['_CLUSTERCONFIG_SECONDARYCONNECTIONS']._serialized_end=2567
  _globals['_HOST']._serialized_start=2590
  _globals['_HOST']._serialized_end=3043
  _globals['_HOST_ROLE']._serialized_start=2929
  _globals['_HOST_ROLE']._serialized_end=2978
  _globals['_HOST_HEALTH']._serialized_start=1108
  _globals['_HOST_HEALTH']._serialized_end=1171
  _globals['_SERVICE']._serialized_start=3046
  _globals['_SERVICE']._serialized_end=3273
  _globals['_SERVICE_TYPE']._serialized_start=3179
  _globals['_SERVICE_TYPE']._serialized_end=3222
  _globals['_SERVICE_HEALTH']._serialized_start=1108
  _globals['_SERVICE_HEALTH']._serialized_end=1157
  _globals['_RESOURCES']._serialized_start=3275
  _globals['_RESOURCES']._serialized_end=3355
  _globals['_ACCESS']._serialized_start=3357
  _globals['_ACCESS']._serialized_end=3401
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings


GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/organizationmanager/v1/saml/certificate_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ClusterExtension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Required. Extension name."""
    cluster_id: builtins.str
    """Required. ID of the ClickHouse cluster."""
    version: builtins.str
    """Required. Extension version."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name", "version", b"version"]) -> None: ...

global___ClusterExtension = ClusterExtension

@typing.final
class ClusterExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTENSIONS_FIELD_NUMBER: builtins.int
    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterExtension]: ...
    def __init__(
        self,
        *,
        extensions: collections.abc.Iterable[global___ClusterExtension] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["extensions", b"extensions"]) -> None: ...

global___ClusterExtensions = ClusterExtensions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/certificatemanager/v1/certificate_content_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/certificatemanager/v1/certificate_content_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDyandex/cloud/certificatemanager/v1/certificate_content_service.proto\x12\"yandex.cloud.certificatemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"m\n\x1dGetCertificateContentResponse\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\x12\x19\n\x11\x63\x65rtificate_chain\x18\x03 \x03(\t\x12\x13\n\x0bprivate_key\x18\x04 \x01(\tJ\x04\x08\x02\x10\x03\"\x9c\x01\n\x1cGetCertificateContentRequest\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12P\n\x12private_key_format\x18\x03 \x01(\x0e\x32\x34.yandex.cloud.certificatemanager.v1.PrivateKeyFormat\"\x9c\x02\n\x1eGetExCertificateContentRequest\x12\"\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12L\n\x0f\x66older_and_name\x18\x02 \x01(\x0b\x32\x31.yandex.cloud.certificatemanager.v1.FolderAndNameH\x00\x12\x1c\n\nversion_id\x18\x15 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12P\n\x12private_key_format\x18\x16 \x01(\x0e\x32\x34.yandex.cloud.certificatemanager.v1.PrivateKeyFormatB\x12\n\nidentifier\x12\x04\xc0\xc1\x31\x01J\x04\x08\x03\x10\x15\"}\n\x1fGetExCertificateContentResponse\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x19\n\x11\x63\x65rtificate_chain\x18\x03 \x03(\t\x12\x13\n\x0bprivate_key\x18\x04 \x01(\t\"Y\n\rFolderAndName\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\'\n\x10\x63\x65rtificate_name\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100*L\n\x10PrivateKeyFormat\x12\"\n\x1ePRIVATE_KEY_FORMAT_UNSPECIFIED\x10\x00\x12\t\n\x05PKCS1\x10\x01\x12\t\n\x05PKCS8\x10\x02\x32\xb9\x03\n\x19\x43\x65rtificateContentService\x12\xd4\x01\n\x03Get\x12@.yandex.cloud.certificatemanager.v1.GetCertificateContentRequest\x1a\x41.yandex.cloud.certificatemanager.v1.GetCertificateContentResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/certificate-manager/v1/certificates/{certificate_id}:getContent\x12\xc4\x01\n\x05GetEx\x12\x42.yandex.cloud.certificatemanager.v1.GetExCertificateContentRequest\x1a\x43.yandex.cloud.certificatemanager.v1.GetExCertificateContentResponse\"2\x82\xd3\xe4\x93\x02,\x12*/certificate-manager/v1/certificates:getExB\x83\x01\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.certificatemanager.v1.certificate_content_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanager'
  _globals['_GETEXCERTIFICATECONTENTREQUEST'].oneofs_by_name['identifier']._loaded_options = None
  _globals['_GETEXCERTIFICATECONTENTREQUEST'].oneofs_by_name['identifier']._serialized_options = b'\300\3011\001'
  _globals['_GETEXCERTIFICATECONTENTREQUEST'].fields_by_name['certificate_id']._loaded_options = None
  _globals['_GETEXCERTIFICATECONTENTREQUEST'].fields_by_name['certificate_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GETEXCERTIFICATECONTENTREQUEST'].fields_by_name['version_id']._loaded_options = None
  _globals['_GETEXCERTIFICATECONTENTREQUEST'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_FOLDERANDNAME'].fields_by_name['folder_id']._loaded_options = None
  _globals['_FOLDERANDNAME'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_FOLDERANDNAME'].fields_by_name['certificate_name']._loaded_options = None
  _globals['_FOLDERANDNAME'].fields_by_name['certificate_name']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_CERTIFICATECONTENTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CERTIFICATECONTENTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002B\022@/certificate-manager/v1/certificates/{certificate_id}:getContent'
  _globals['_CERTIFICATECONTENTSERVICE'].methods_by_name['GetEx']._loaded_options = None
  _globals['_CERTIFICATECONTENTSERVICE'].methods_by_name['GetEx']._serialized_options = b'\202\323\344\223\002,\022*/certificate-manager/v1/certificates:getEx'
  _globals['_PRIVATEKEYFORMAT']._serialized_start=944
  _globals['_PRIVATEKEYFORMAT']._serialized_end=1020
  _globals['_GETCERTIFICATECONTENTRESPONSE']._serialized_start=169
  _globals['_GETCERTIFICATECONTENTRESPONSE']._serialized_end=278
  _globals['_GETCERTIFICATECONTENTREQUEST']._serialized_start=281
  _globals['_GETCERTIFICATECONTENTREQUEST']._serialized_end=437
  _globals['_GETEXCERTIFICATECONTENTREQUEST']._serialized_start=440
  _globals['_GETEXCERTIFICATECONTENTREQUEST']._serialized_end=724
  _globals['_GETEXCERTIFICATECONTENTRESPONSE']._serialized_start=726
  _globals['_GETEXCERTIFICATECONTENTRESPONSE']._serialized_end=851
  _globals['_FOLDERANDNAME']._serialized_start=853
  _globals['_FOLDERANDNAME']._serialized_end=942
  _globals['_CERTIFICATECONTENTSERVICE']._serialized_start=1023
  _globals['_CERTIFICATECONTENTSERVICE']._serialized_end=1464
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.searchapi.v2.search_query_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Role:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Role.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ROLE_UNSPECIFIED: _Role.ValueType  # 0
    ROLE_USER: _Role.ValueType  # 1
    """The message is sent by the user."""
    ROLE_ASSISTANT: _Role.ValueType  # 2
    """The message is sent by the model."""

class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...

ROLE_UNSPECIFIED: Role.ValueType  # 0
ROLE_USER: Role.ValueType  # 1
"""The message is sent by the user."""
ROLE_ASSISTANT: Role.ValueType  # 2
"""The message is sent by the model."""
global___Role = Role

@typing.final
class GenSearchMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    content: builtins.str
    """Text of user query or the model's response (depending on the role value)."""
    role: global___Role.ValueType
    """Message sender's role"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        role: global___Role.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "role", b"role"]) -> None: ...

global___GenSearchMessage = GenSearchMessage

@typing.final
class GenSearchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class SiteOption(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SITE_FIELD_NUMBER: builtins.int
        @property
        def site(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Restricts the search to the specific websites."""

        def __init__(
            self,
            *,
            site: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["site", b"site"]) -> None: ...

    @typing.final
    class UrlOption(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        URL_FIELD_NUMBER: builtins.int
        @property
        def url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Restricts the search to the specific pages."""

        def __init__(
            self,
            *,
            url: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

    @typing.final
    class HostOption(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HOST_FIELD_NUMBER: builtins.int
        @property
        def host(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Restricts the search to the specific hosts."""

        def __init__(
            self,
            *,
            host: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["host", b"host"]) -> None: ...

    @typing.final
    class SearchFilter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _DocFormat:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _DocFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GenSearchRequest.SearchFilter._DocFormat.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            DOC_FORMAT_UNSPECIFIED: GenSearchRequest.SearchFilter._DocFormat.ValueType  # 0
            DOC_FORMAT_PDF: GenSearchRequest.SearchFilter._DocFormat.ValueType  # 1
            DOC_FORMAT_XLS: GenSearchRequest.SearchFilter._DocFormat.ValueType  # 2
            DOC_FORMAT_ODS: GenSearchRequest.SearchFilter._DocFormat.ValueType  # 3
            DOC_FORMAT_RTF: GenSearchRequest.SearchFilter._DocFormat.ValueType  # 4
            DOC_FORMAT_PPT: GenSearchRequest.SearchFilter._DocFormat.ValueType  # 5
            DOC_FORMAT_ODP: GenSearchRequest.SearchFilter._DocFormat.ValueType  # 6
            DOC_FORMAT_SWF: GenSearchRequest.SearchFilter._DocFormat.ValueType  # 7
            DOC_FORMAT_ODT: GenSearchRequest.SearchFilter._DocFormat.ValueType  # 8
            DOC_FORMAT_ODG: GenSearchRequest.SearchFilter._DocFormat.ValueType  # 9
            DOC_FORMAT_DOC: GenSearchRequest.SearchFilter._DocFormat.ValueType  # 10

        class DocFormat(_DocFormat, metaclass=_DocFormatEnumTypeWrapper): ...
        DOC_FORMAT_UNSPECIFIED: GenSearchRequest.SearchFilter.DocFormat.ValueType  # 0
        DOC_FORMAT_PDF: GenSearchRequest.SearchFilter.DocFormat.ValueType  # 1
        DOC_FORMAT_XLS: GenSearchRequest.SearchFilter.DocFormat.ValueType  # 2
        DOC_FORMAT_ODS: GenSearchRequest.SearchFilter.DocFormat.ValueType  # 3
        DOC_FORMAT_RTF: GenSearchRequest.SearchFilter.DocFormat.ValueType  # 4
        DOC_FORMAT_PPT: GenSearchRequest.SearchFilter.DocFormat.ValueType  # 5
        DOC_FORMAT_ODP: GenSearchRequest.SearchFilter.DocFormat.ValueType  # 6
        DOC_FORMAT_SWF: GenSearchRequest.SearchFilter.DocFormat.ValueType  # 7
        DOC_FORMAT_ODT: GenSearchRequest.SearchFilter.DocFormat.ValueType  # 8
        DOC_FORMAT_ODG: GenSearchRequest.SearchFilter.DocFormat.ValueType  # 9
        DOC_FORMAT_DOC: GenSearchRequest.SearchFilter.DocFormat.ValueType  # 10

        DATE_FIELD_NUMBER: builtins.int
        LANG_FIELD_NUMBER: builtins.int
        FORMAT_FIELD_NUMBER: builtins.int
        date: builtins.str
        """Restrict by document date. See https://yandex.ru/support/search/ru/query-language/search-operators details."""
        lang: builtins.str
        """Restrict by document language. Use ISO 639-1 language codes."""
        format: global___GenSearchRequest.SearchFilter.DocFormat.ValueType
        """Restrict by document format."""
        def __init__(
            self,
            *,
            date: builtins.str = ...,
            lang: builtins.str = ...,
            format: global___GenSearchRequest.SearchFilter.DocFormat.ValueType = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["date", b"date", "filter_options", b"filter_options", "format", b"format", "lang", b"lang"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["date", b"date", "filter_options", b"filter_options", "format", b"format", "lang", b"lang"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["filter_options", b"filter_options"]) -> typing.Literal["date", "lang", "format"] | None: ...

    MESSAGES_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    SITE_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    FIX_MISSPELL_FIELD_NUMBER: builtins.int
    ENABLE_NRFM_DOCS_FIELD_NUMBER: builtins.int
    SEARCH_FILTERS_FIELD_NUMBER: builtins.int
    SEARCH_TYPE_FIELD_NUMBER: builtins.int
    GET_PARTIAL_RESULTS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder."""
    fix_misspell: builtins.bool
    """Fix query misspells."""
    enable_nrfm_docs: builtins.bool
    """Use the documents inaccessible from the site's front page."""
    search_type: yandex.cloud.searchapi.v2.search_query_pb2.SearchQuery.SearchType.ValueType
    """Search type that determines the domain name that will be used for the search queries."""
    get_partial_results: builtins.bool
    """Get partial results"""
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenSearchMessage]:
        """Single search query or a search query with context in the form of chat with the model."""

    @property
    def site(self) -> global___GenSearchRequest.SiteOption: ...
    @property
    def host(self) -> global___GenSearchRequest.HostOption: ...
    @property
    def url(self) -> global___GenSearchRequest.UrlOption: ...
    @property
    def search_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenSearchRequest.SearchFilter]:
        """Restricts the search by date, document formats or language."""

    @property
    def metadata(self) -> yandex.cloud.searchapi.v2.search_query_pb2.SearchMetadata:
        """Search flags"""

    def __init__(
        self,
        *,
        messages: collections.abc.Iterable[global___GenSearchMessage] | None = ...,
        folder_id: builtins.str = ...,
        site: global___GenSearchRequest.SiteOption | None = ...,
        host: global___GenSearchRequest.HostOption | None = ...,
        url: global___GenSearchRequest.UrlOption | None = ...,
        fix_misspell: builtins.bool = ...,
        enable_nrfm_docs: builtins.bool = ...,
        search_filters: collections.abc.Iterable[global___GenSearchRequest.SearchFilter] | None = ...,
        search_type: yandex.cloud.searchapi.v2.search_query_pb2.SearchQuery.SearchType.ValueType = ...,
        get_partial_results: builtins.bool = ...,
        metadata: yandex.cloud.searchapi.v2.search_query_pb2.SearchMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["host", b"host", "metadata", b"metadata", "site", b"site", "site_options", b"site_options", "url", b"url"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["enable_nrfm_docs", b"enable_nrfm_docs", "fix_misspell", b"fix_misspell", "folder_id", b"folder_id", "get_partial_results", b"get_partial_results", "host", b"host", "messages", b"messages", "metadata", b"metadata", "search_filters", b"search_filters", "search_type", b"search_type", "site", b"site", "site_options", b"site_options", "url", b"url"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["site_options", b"site_options"]) -> typing.Literal["site", "host", "url"] | None: ...

global___GenSearchRequest = GenSearchRequest

@typing.final
class GenSearchResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Source(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        URL_FIELD_NUMBER: builtins.int
        TITLE_FIELD_NUMBER: builtins.int
        USED_FIELD_NUMBER: builtins.int
        url: builtins.str
        """Document URL."""
        title: builtins.str
        """Document title."""
        used: builtins.bool
        """The document was used in the answer."""
        def __init__(
            self,
            *,
            url: builtins.str = ...,
            title: builtins.str = ...,
            used: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["title", b"title", "url", b"url", "used", b"used"]) -> None: ...

    @typing.final
    class SearchQuery(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TEXT_FIELD_NUMBER: builtins.int
        REQ_ID_FIELD_NUMBER: builtins.int
        text: builtins.str
        """Query text."""
        req_id: builtins.str
        """Query ID in Yandex Search."""
        def __init__(
            self,
            *,
            text: builtins.str = ...,
            req_id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["req_id", b"req_id", "text", b"text"]) -> None: ...

    MESSAGE_FIELD_NUMBER: builtins.int
    SOURCES_FIELD_NUMBER: builtins.int
    SEARCH_QUERIES_FIELD_NUMBER: builtins.int
    FIXED_MISSPELL_QUERY_FIELD_NUMBER: builtins.int
    IS_ANSWER_REJECTED_FIELD_NUMBER: builtins.int
    IS_BULLET_ANSWER_FIELD_NUMBER: builtins.int
    HINTS_FIELD_NUMBER: builtins.int
    fixed_misspell_query: builtins.str
    """The text of the search query with fixed misspells."""
    is_answer_rejected: builtins.bool
    """The model failed to answer due to the ethical concerns."""
    is_bullet_answer: builtins.bool
    """A bullet answer in case the model cannot give a proper response and returns a set of bullets with various data."""
    @property
    def message(self) -> global___GenSearchMessage:
        """The text of the generative response."""

    @property
    def sources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenSearchResponse.Source]:
        """The documents used to form the generative response."""

    @property
    def search_queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenSearchResponse.SearchQuery]:
        """The search queries, refined by the YandexGPT model and used for the generative response."""

    @property
    def hints(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Search hints"""

    def __init__(
        self,
        *,
        message: global___GenSearchMessage | None = ...,
        sources: collections.abc.Iterable[global___GenSearchResponse.Source] | None = ...,
        search_queries: collections.abc.Iterable[global___GenSearchResponse.SearchQuery] | None = ...,
        fixed_misspell_query: builtins.str = ...,
        is_answer_rejected: builtins.bool = ...,
        is_bullet_answer: builtins.bool = ...,
        hints: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["fixed_misspell_query", b"fixed_misspell_query", "hints", b"hints", "is_answer_rejected", b"is_answer_rejected", "is_bullet_answer", b"is_bullet_answer", "message", b"message", "search_queries", b"search_queries", "sources", b"sources"]) -> None: ...

global___GenSearchResponse = GenSearchResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.compute.v1.reserved_instance_pool_pb2
import yandex.cloud.compute.v1.reserved_instance_pool_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ReservedInstancePoolServiceStub:
    """A set of methods for managing reserved instance pool resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.GetReservedInstancePoolRequest,
        yandex.cloud.compute.v1.reserved_instance_pool_pb2.ReservedInstancePool,
    ]
    """Returns the specified reserved instance pool resource.

    To get the list of available reserved instance pool resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolsRequest,
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolsResponse,
    ]
    """Retrieves the list of reserved instance pool resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.CreateReservedInstancePoolRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an reserved instance pool in the specified folder.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.UpdateReservedInstancePoolRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified reserved instance pool."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.DeleteReservedInstancePoolRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified reserved instance pool."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolOperationsRequest,
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolOperationsResponse,
    ]
    """Lists operations for the specified reserved instance pool."""

    ListInstances: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolInstancesRequest,
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolInstancesResponse,
    ]
    """Retrieves the list of instances, using the specified reserved instance pool."""

class ReservedInstancePoolServiceAsyncStub:
    """A set of methods for managing reserved instance pool resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.GetReservedInstancePoolRequest,
        yandex.cloud.compute.v1.reserved_instance_pool_pb2.ReservedInstancePool,
    ]
    """Returns the specified reserved instance pool resource.

    To get the list of available reserved instance pool resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolsRequest,
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolsResponse,
    ]
    """Retrieves the list of reserved instance pool resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.CreateReservedInstancePoolRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an reserved instance pool in the specified folder.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.UpdateReservedInstancePoolRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified reserved instance pool."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.DeleteReservedInstancePoolRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified reserved instance pool."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolOperationsRequest,
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolOperationsResponse,
    ]
    """Lists operations for the specified reserved instance pool."""

    ListInstances: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolInstancesRequest,
        yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolInstancesResponse,
    ]
    """Retrieves the list of instances, using the specified reserved instance pool."""

class ReservedInstancePoolServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing reserved instance pool resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.GetReservedInstancePoolRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.reserved_instance_pool_pb2.ReservedInstancePool, collections.abc.Awaitable[yandex.cloud.compute.v1.reserved_instance_pool_pb2.ReservedInstancePool]]:
        """Returns the specified reserved instance pool resource.

        To get the list of available reserved instance pool resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolsResponse]]:
        """Retrieves the list of reserved instance pool resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.CreateReservedInstancePoolRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an reserved instance pool in the specified folder.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.UpdateReservedInstancePoolRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified reserved instance pool."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.DeleteReservedInstancePoolRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified reserved instance pool."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolOperationsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolOperationsResponse]]:
        """Lists operations for the specified reserved instance pool."""

    @abc.abstractmethod
    def ListInstances(
        self,
        request: yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolInstancesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolInstancesResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.reserved_instance_pool_service_pb2.ListReservedInstancePoolInstancesResponse]]:
        """Retrieves the list of instances, using the specified reserved instance pool."""

def add_ReservedInstancePoolServiceServicer_to_server(servicer: ReservedInstancePoolServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Artifact(google.protobuf.message.Message):
    """A Artifact resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Kind:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _KindEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Artifact._Kind.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        KIND_UNSPECIFIED: Artifact._Kind.ValueType  # 0
        FOLDER: Artifact._Kind.ValueType  # 1
        """Artifact kind is folder."""
        PACKAGE: Artifact._Kind.ValueType  # 2
        """Artifact kind is package."""
        ARTIFACT: Artifact._Kind.ValueType  # 3
        """Artifact kind is artifact."""

    class Kind(_Kind, metaclass=_KindEnumTypeWrapper): ...
    KIND_UNSPECIFIED: Artifact.Kind.ValueType  # 0
    FOLDER: Artifact.Kind.ValueType  # 1
    """Artifact kind is folder."""
    PACKAGE: Artifact.Kind.ValueType  # 2
    """Artifact kind is package."""
    ARTIFACT: Artifact.Kind.ValueType  # 3
    """Artifact kind is artifact."""

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Artifact._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Artifact._Status.ValueType  # 0
        CREATING: Artifact._Status.ValueType  # 1
        """Artifact status is being created."""
        ACTIVE: Artifact._Status.ValueType  # 2
        """Artifact status is ready to use."""
        DELETING: Artifact._Status.ValueType  # 3
        """Artifact status is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Artifact.Status.ValueType  # 0
    CREATING: Artifact.Status.ValueType  # 1
    """Artifact status is being created."""
    ACTIVE: Artifact.Status.ValueType  # 2
    """Artifact status is ready to use."""
    DELETING: Artifact.Status.ValueType  # 3
    """Artifact status is being deleted."""

    ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    MODIFIED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Output only. ID of the artifact."""
    path: builtins.str
    """Path where the artifact is located."""
    name: builtins.str
    """Name of the artifact."""
    kind: global___Artifact.Kind.ValueType
    """Kind of the artifact."""
    status: global___Artifact.Status.ValueType
    """Output only. Status of the artifact."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Output only. Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Output only. Modification timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        path: builtins.str = ...,
        name: builtins.str = ...,
        kind: global___Artifact.Kind.ValueType = ...,
        status: global___Artifact.Status.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "modified_at", b"modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "id", b"id", "kind", b"kind", "modified_at", b"modified_at", "name", b"name", "path", b"path", "status", b"status"]) -> None: ...

global___Artifact = Artifact
